@@ -46,7 +46,7 @@ public class FileMessageFactory {
     /**
      * The number of bytes that we read from file
      */
-    public static final int READ_SIZE = 1024 * 10; // 10 KiB
+    public static final int READ_SIZE = 1024 * 10; // 10kb
 
     /**
      * The file that we are reading/writing
@@ -97,7 +97,7 @@ public class FileMessageFactory {
      * Messages received out of order are held in the buffer until required. If everything is worked as expected,
      * messages will spend very little time in the buffer.
      */
-    protected final Map<Long,FileMessage> msgBuffer = new ConcurrentHashMap<>();
+    protected final Map<Long, FileMessage> msgBuffer = new ConcurrentHashMap<>();
 
     /**
      * The bytes that we hold the data in, not thread safe.
@@ -121,7 +121,7 @@ public class FileMessageFactory {
     /**
      * The time this instance was last modified.
      */
-    protected long lastModified;
+    protected long lastModified = 0;
 
     /**
      * The maximum time (in seconds) this instance will be allowed to exist from lastModifiedTime.
@@ -130,7 +130,7 @@ public class FileMessageFactory {
 
     /**
      * Private constructor, either instantiates a factory to read or write. <BR>
-     * When openForWrite==true, then the file f will be created and an output stream is opened to write to it. <BR>
+     * When openForWrite==true, then a the file, f, will be created and an output stream is opened to write to it. <BR>
      * When openForWrite==false, an input stream is opened, the file has to exist.
      *
      * @param f            File - the file to be read/written
@@ -143,8 +143,8 @@ public class FileMessageFactory {
     private FileMessageFactory(File f, boolean openForWrite) throws FileNotFoundException, IOException {
         this.file = f;
         this.openForWrite = openForWrite;
-        if (log.isTraceEnabled()) {
-            log.trace("FileMessageFactory open file " + f + " write " + openForWrite);
+        if (log.isDebugEnabled()) {
+            log.debug("open file " + f + " write " + openForWrite);
         }
         if (openForWrite) {
             if (!file.exists()) {
@@ -221,8 +221,8 @@ public class FileMessageFactory {
         if (!openForWrite) {
             throw new IllegalArgumentException(sm.getString("fileMessageFactory.cannotWrite"));
         }
-        if (log.isTraceEnabled()) {
-            log.trace("Message " + msg + " data " + HexUtils.toHexString(msg.getData()) + " data length " +
+        if (log.isDebugEnabled()) {
+            log.debug("Message " + msg + " data " + HexUtils.toHexString(msg.getData()) + " data length " +
                     msg.getDataLength() + " out " + out);
         }
 
@@ -244,7 +244,7 @@ public class FileMessageFactory {
         // Have received a new message. Update the last modified time (even if the message is being buffered for now).
         lastModified = System.currentTimeMillis();
 
-        FileMessage next;
+        FileMessage next = null;
         synchronized (this) {
             if (!isWriting) {
                 next = msgBuffer.get(Long.valueOf(lastMessageProcessed.get() + 1));
@@ -328,37 +328,6 @@ public class FileMessageFactory {
         }
     }
 
-    /**
-     * Example usage.
-     *
-     * @param args String[], args[0] - read from filename, args[1] write to filename
-     *
-     * @throws Exception An error occurred
-     *
-     * @deprecated This method will be removed in Tomcat 10.0.x
-     */
-    @Deprecated
-    public static void main(String[] args) throws Exception {
-        System.out.println("Usage: FileMessageFactory fileToBeRead fileToBeWritten");
-        System.out.println("Usage: This will make a copy of the file on the local file system");
-        FileMessageFactory read = getInstance(new File(args[0]), false);
-        FileMessageFactory write = getInstance(new File(args[1]), true);
-        FileMessage msg = new FileMessage(null, args[0], args[0]);
-        msg = read.readMessage(msg);
-        if (msg == null) {
-            System.out.println("Empty input file : " + args[0]);
-            return;
-        }
-        System.out.println("Expecting to write " + msg.getTotalNrOfMsgs() + " messages.");
-        int cnt = 0;
-        while (msg != null) {
-            write.writeMessage(msg);
-            cnt++;
-            msg = read.readMessage(msg);
-        } // while
-        System.out.println("Actually wrote " + cnt + " messages.");
-    }/// main
-
     public File getFile() {
         return file;
     }
