@@ -36,10 +36,14 @@ import org.apache.tomcat.util.net.openssl.ciphers.Cipher;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
- * JSSESupport. Concrete implementation class for JSSE Support classes.
+ * JSSESupport.
+ *
+ * Concrete implementation class for JSSE Support classes.
  *
  * @author EKR
- * @author Craig R. McClanahan Parts cribbed from JSSECertCompat Parts cribbed from CertificatesValve
+ * @author Craig R. McClanahan
+ * Parts cribbed from JSSECertCompat
+ * Parts cribbed from CertificatesValve
  */
 public class JSSESupport implements SSLSupport, SSLSessionManager {
 
@@ -58,25 +62,16 @@ public class JSSESupport implements SSLSupport, SSLSessionManager {
     }
 
     /*
-     * NO-OP method provided to make it easy for other classes in this package to trigger the loading of this class and
-     * the population of the keySizeCache.
+     * NO-OP method provided to make it easy for other classes in this package
+     * to trigger the loading of this class and the population of the
+     * keySizeCache.
      */
     static void init() {
         // NO-OP
     }
 
     private SSLSession session;
-    private final Map<String,List<String>> additionalAttributes;
-
-    /**
-     * @param session SSLSession from which information is to be extracted
-     *
-     * @deprecated This will be removed in Tomcat 10.1.x onwards Use {@link JSSESupport#JSSESupport(SSLSession, Map)}
-     */
-    @Deprecated
-    public JSSESupport(SSLSession session) {
-        this(session, null);
-    }
+    private Map<String,List<String>> additionalAttributes;
 
     public JSSESupport(SSLSession session, Map<String,List<String>> additionalAttributes) {
         this.session = session;
@@ -101,19 +96,17 @@ public class JSSESupport implements SSLSupport, SSLSessionManager {
     }
 
     @Override
-    public X509Certificate[] getPeerCertificateChain() throws IOException {
+    public java.security.cert.X509Certificate[] getPeerCertificateChain() throws IOException {
         // Look up the current SSLSession
         if (session == null) {
             return null;
         }
 
-        Certificate[] certs;
+        Certificate [] certs=null;
         try {
             certs = session.getPeerCertificates();
-        } catch (Throwable t) {
-            if (log.isDebugEnabled()) {
-                log.debug(sm.getString("jsseSupport.clientCertError"), t);
-            }
+        } catch( Throwable t ) {
+            log.debug(sm.getString("jsseSupport.clientCertError"), t);
             return null;
         }
 
@@ -121,32 +114,37 @@ public class JSSESupport implements SSLSupport, SSLSessionManager {
     }
 
 
-    private static X509Certificate[] convertCertificates(Certificate[] certs) {
-        if (certs == null) {
+    private static java.security.cert.X509Certificate[] convertCertificates(Certificate[] certs) {
+        if( certs==null ) {
             return null;
         }
 
-        X509Certificate[] x509Certs = new X509Certificate[certs.length];
-        for (int i = 0; i < certs.length; i++) {
-            if (certs[i] instanceof X509Certificate) {
+        java.security.cert.X509Certificate [] x509Certs =
+            new java.security.cert.X509Certificate[certs.length];
+        for(int i=0; i < certs.length; i++) {
+            if (certs[i] instanceof java.security.cert.X509Certificate ) {
                 // always currently true with the JSSE 1.1.x
-                x509Certs[i] = (X509Certificate) certs[i];
+                x509Certs[i] = (java.security.cert.X509Certificate) certs[i];
             } else {
                 try {
-                    byte[] buffer = certs[i].getEncoded();
-                    CertificateFactory cf = CertificateFactory.getInstance("X.509");
-                    ByteArrayInputStream stream = new ByteArrayInputStream(buffer);
-                    x509Certs[i] = (X509Certificate) cf.generateCertificate(stream);
-                } catch (Exception e) {
-                    log.info(sm.getString("jsseSupport.certTranslationError", certs[i]), e);
+                    byte [] buffer = certs[i].getEncoded();
+                    CertificateFactory cf =
+                        CertificateFactory.getInstance("X.509");
+                    ByteArrayInputStream stream =
+                        new ByteArrayInputStream(buffer);
+                    x509Certs[i] = (java.security.cert.X509Certificate)
+                            cf.generateCertificate(stream);
+                } catch(Exception ex) {
+                    log.info(sm.getString(
+                            "jsseSupport.certTranslationError", certs[i]), ex);
                     return null;
                 }
             }
-            if (log.isTraceEnabled()) {
+            if(log.isTraceEnabled()) {
                 log.trace("Cert #" + i + " = " + x509Certs[i]);
             }
         }
-        if (x509Certs.length < 1) {
+        if(x509Certs.length < 1) {
             return null;
         }
         return x509Certs;
@@ -169,17 +167,18 @@ public class JSSESupport implements SSLSupport, SSLSessionManager {
     }
 
     @Override
-    public String getSessionId() throws IOException {
+    public String getSessionId()
+        throws IOException {
         // Look up the current SSLSession
         if (session == null) {
             return null;
         }
         // Expose ssl_session (getId)
-        byte[] ssl_session = session.getId();
-        if (ssl_session == null || ssl_session.length == 0) {
+        byte [] ssl_session = session.getId();
+        if ( ssl_session == null) {
             return null;
         }
-        StringBuilder buf = new StringBuilder();
+        StringBuilder buf=new StringBuilder();
         for (byte b : ssl_session) {
             String digit = Integer.toHexString(b);
             if (digit.length() < 2) {
@@ -210,9 +209,9 @@ public class JSSESupport implements SSLSupport, SSLSessionManager {
     @Override
     public String getProtocol() throws IOException {
         if (session == null) {
-            return null;
+           return null;
         }
-        return session.getProtocol();
+       return session.getProtocol();
     }
 
     @Override
@@ -220,7 +219,7 @@ public class JSSESupport implements SSLSupport, SSLSessionManager {
         if (additionalAttributes == null) {
             return null;
         }
-        return StringUtils.join(additionalAttributes.get(REQUESTED_PROTOCOL_VERSIONS_KEY));
+        return StringUtils.join(additionalAttributes.get(SSLSupport.REQUESTED_PROTOCOL_VERSIONS_KEY));
     }
 
     @Override
@@ -228,7 +227,7 @@ public class JSSESupport implements SSLSupport, SSLSessionManager {
         if (additionalAttributes == null) {
             return null;
         }
-        return StringUtils.join(additionalAttributes.get(REQUESTED_CIPHERS_KEY));
+        return StringUtils.join(additionalAttributes.get(SSLSupport.REQUESTED_CIPHERS_KEY));
     }
 }
 
